<?xml version="1.0"?> 
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"  xmlns:java="java.util.ResourceBundle" exclude-result-prefixes="java">
<xsl:variable name="resources" select="java:getBundle('UIMessages')"/>
<!-- This stylesheet is used to convert the execution context to html for display on the process debug screen. -->
<!-- When you run a process using the debug facility the output you see on the debug screen is provided by this style sheet. -->
 <xsl:template match="process-item">
 <td><table>
  <tr><td class="lbl"><xsl:value-of select="java:getString($resources,'executionContextToHTML.service')"/></td><td><div class="dfld"><xsl:value-of select="@process-name"/></div></td></tr>
  <tr><td class="lbl"><xsl:value-of select="java:getString($resources,'executionContextToHTML.itemType')"/></td><td><div class="dfld"><xsl:call-template name="getItemType"/></div></td></tr>
  <tr><td class="lbl"><xsl:value-of select="java:getString($resources,'executionContextToHTML.itemName')"/></td><td><div class="dfld"><xsl:value-of select="@name"/></div></td></tr>
 </table></td>
 <xsl:apply-templates />
 </xsl:template>

 <xsl:template match="symbolTable">
  <xsl:apply-templates select="namespace" />
 </xsl:template>

 <!-- Generate a list, sorted alphabetically by symbol name, of the symbols in the symbol table. -->
 <xsl:template match="namespace">
  <xsl:if test="variable">

<table border="1" cellpadding="1" cellspacing="1" width="99%"><tr align="center" bgcolor="#00407A"><td colspan="3" class="debugtitle"><xsl:value-of select="java:getString($resources,'executionContextToHTML.namespace')"> 
	<parameters>
                       <parameter index="0">
                                <xsl:value-of select="@name" />
                        </parameter>
        </parameters>
</xsl:value-of>
</td></tr>
<tr bgcolor="#00407A">
 <td width="12%" class="debugtitle"> <xsl:value-of select="java:getString($resources,'executionContextToHTML.name')"/></td>
 <xsl:if test="variable/@type">
 <td width="9%" class="debugtitle"><xsl:value-of select="java:getString($resources,'executionContextToHTML.type')"/></td>
 </xsl:if>
 <td width="80%" class="debugtitle"><xsl:value-of select="java:getString($resources,'executionContextToHTML.value')"/></td></tr>
<xsl:apply-templates select="variable">
 <xsl:sort data-type="text" order="ascending" select="@name"/>
</xsl:apply-templates>
</table>
  </xsl:if>
 </xsl:template>

<!-- Generate a row containing the data about a single symbol. -->
<xsl:template match="variable">
 <tr valign="top" bgcolor="#DAE3EC">
  <xsl:attribute name="id">
   <xsl:value-of select="@name"/><xsl:value-of select="position()" />
   </xsl:attribute>
  <!-- <xsl:attribute name="onclick">
   <xsl:text>SelectRow(</xsl:text> 
   '<xsl:value-of select="@name"/><xsl:value-of select="position()" />'
   <xsl:text>)</xsl:text>  
 </xsl:attribute>--> 
 <td valign="top" class="lbl"><xsl:value-of select="@name"/></td>
 <xsl:if test="@type">
 <td valign="top"><div class="info1">
 <xsl:attribute name = "title" >Declared Type: <xsl:value-of select="@declaredType"/></xsl:attribute>
 <xsl:value-of select="@type"/></div></td>
 </xsl:if>
 <!-- The if statement makes sure a symbol with a null value doesn't produce an empty, and therefore collapsed, table cell. -->
 <td><xsl:if test="not(boolean(string(.)))">&#160;</xsl:if><pre style="margin=0">
   <div class="info1">
   <xsl:call-template name="replaceWithBreaks">
       <xsl:with-param name="initial" select="." />
   </xsl:call-template></div>
</pre></td>
 </tr>
</xsl:template>

<xsl:template name="replaceWithBreaks">
   <xsl:param name="initial" />
   <xsl:param name="from" select="'\r\n'" />
   <xsl:param name="to">
      <br />
   </xsl:param>
   <xsl:choose>
      <xsl:when test="contains($initial, $from)">
         <xsl:value-of select="substring-before($initial, $from)" />
         <xsl:copy-of select="$to" />
         <xsl:call-template name="replaceWithBreaks">
            <xsl:with-param name="initial"
                            select="substring-after($initial, $from)" />
            <xsl:with-param name="from" select="$from" />
            <xsl:with-param name="to" select="$to" />
         </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
         <xsl:value-of select="$initial" />
      </xsl:otherwise>
   </xsl:choose>
</xsl:template>                

<!-- For TaskAction and WebComponent items provide the same name that is displayed in the authoring environment. -->
<xsl:template name="getItemType">
 <xsl:param name="itemType" select="@component-name"/>
 <xsl:choose>
  <xsl:when test="$itemType = 'Step'"><xsl:text>Integration Component</xsl:text></xsl:when>
  <xsl:when test="$itemType = 'TaskAction'"><xsl:text>Modify Task</xsl:text></xsl:when>
  <xsl:when test="$itemType = 'Script'"><xsl:text>Server Script</xsl:text></xsl:when>
  <xsl:when test="$itemType = 'TaskSender'"><xsl:text>Send Alert</xsl:text></xsl:when>
  <xsl:when test="$itemType = 'ExitPoint'"><xsl:text>Exit Point</xsl:text></xsl:when>
  <xsl:when test="$itemType = 'Exception'"><xsl:text>Error End Event</xsl:text></xsl:when>
  <xsl:when test="$itemType = 'Switch'"><xsl:text>Decision Gateway</xsl:text></xsl:when>
  <xsl:when test="$itemType = 'SubProcess'"><xsl:text>Nested Service</xsl:text></xsl:when>
  <xsl:when test="$itemType = 'TrackingPoint'"><xsl:text>Tracking Event</xsl:text></xsl:when>
  <xsl:when test="$itemType = 'InvokeUca'"><xsl:text>Invoke UCA</xsl:text></xsl:when>
  <xsl:otherwise><xsl:value-of select="$itemType"/></xsl:otherwise>
 </xsl:choose>
 </xsl:template>
</xsl:stylesheet>