<?xml version="1.0"?>

<xsl:stylesheet
    version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:java="http://xml.apache.org/xslt/java"
    exclude-result-prefixes="java">

    <xsl:output method="xml" indent="yes"/>

    <xsl:key name="outputParameter" match="//processParameter[parameterType='2']" use="processParameterId" />

    <xsl:template match="/teamworks">
        <teamworks version="Kepler">
            <xsl:apply-templates/>
        </teamworks>
    </xsl:template>

    <xsl:template match="CoachButtons">
        <CoachButtons>
            <endStateId><xsl:choose>
                <xsl:when test='buttonLabel[@isNull="true"] or string-length(buttonLabel) = 0'><xsl:value-of select="coachButtonId" /></xsl:when>
                <xsl:otherwise><xsl:value-of select="buttonLabel" /></xsl:otherwise>
            </xsl:choose></endStateId>
            <xsl:apply-templates />
        </CoachButtons>
    </xsl:template>

    <xsl:template match="SwitchCondition">
        <SwitchCondition>
            <endStateId><xsl:value-of select="name" /><xsl:if test="name = 1">" ("<xsl:value-of select="../switchConditionId"/>")"</xsl:if></endStateId>
            <xsl:apply-templates select="@*|node()"/>
        </SwitchCondition>
    </xsl:template>

    <xsl:template match="teamworks/connector">
        <connector>
            <xsl:apply-templates select="@*|node()"/>
            <connectorType><xsl:choose>
                    <xsl:when test="definition/connector/@type = 'teamworks.connector.ReflectionConnector'">1</xsl:when>
                    <xsl:when test="definition/connector/@type = 'teamworks.connector.SOAPConnector'">2</xsl:when>
                    <xsl:otherwise>0</xsl:otherwise>
                </xsl:choose></connectorType>
        </connector>
    </xsl:template>

    <xsl:template match="priority[@id and @name]">
        <priority>
            <xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
            <xsl:attribute name="name"><xsl:value-of select="substring(@name, 1, 64)"/></xsl:attribute>
            <description isNull="true"/>
            <authorFolder>/System/Priorities</authorFolder>
            <xsl:apply-templates  select="node()[local-name() != 'authorFolder']"/>
        </priority>
    </xsl:template>

    <xsl:template match="calendar[@id and @name]">
        <calendar>
            <xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
            <xsl:attribute name="name"><xsl:value-of select="substring(@name, 1, 64)"/></xsl:attribute>
            <name><xsl:value-of select="substring(@name, 1, 64)"/></name>
            <description isNull="true"/>
            <authorFolder>/System/Calendars</authorFolder>
            <xsl:apply-templates select="node()[local-name() != 'authorFolder']" />
        </calendar>
    </xsl:template>

    <xsl:template match="layout[@id and @name='Simple Pie chart']">
        <layout>
            <xsl:attribute name="id"><xsl:value-of select="@id"/></xsl:attribute>
            <xsl:attribute name="name">Simple Pie Chart</xsl:attribute>
            <xsl:apply-templates select="node()"/>
        </layout>
    </xsl:template>

    <!-- drop the original name from the calendar -->
    <xsl:template match="calendar/name"/>

    <xsl:template match="TWComponent[taskActionId]">
        <TWComponent>
            <xsl:apply-templates/>
            <xsl:choose>
                <xsl:when test="string-length(newCustomStatus) = 0">
                    <newCustomStatus>0</newCustomStatus>
                    <newCustomStatusScript isNull="true"/>
                </xsl:when>
                <xsl:when test="java:com.lombardisoftware.expimp.PSExportImportUtils.isValueNumeric(newCustomStatus)">
                    <newCustomStatus><xsl:value-of select="newCustomStatus"/></newCustomStatus>
                    <newCustomStatusScript isNull="true"/>
                </xsl:when>
                <xsl:otherwise>
                    <newCustomStatus>-1</newCustomStatus>
                    <xsl:variable name="js" select="java:com.lombardisoftware.expimp.PSExportImportUtils.convertFromPointyHashToExpression(newCustomStatus)"/>
                    <xsl:if test="string-length($js) &gt; 255">
                        <xsl:variable name="e">Conversion of newCustomStatus <xsl:value-of select="newCustomStatus"/> from pointy hash to javascript failed. Converted value <xsl:value-of select="$js"/> longer than 255 characters.</xsl:variable>
                        <xsl:value-of select="java:com.lombardisoftware.expimp.PSExportImportUtils.throwException($e)"/>
                    </xsl:if>
                    <newCustomStatusScript><xsl:value-of select="$js"/></newCustomStatusScript>
                </xsl:otherwise>
            </xsl:choose>
            <isReassignActive>false</isReassignActive>
            <reassignOption>1</reassignOption>
            <reassignTo isNull="true"/>
        </TWComponent>
    </xsl:template>

    <!-- Drop the original new custom status value -->
    <xsl:template match="TWComponent[taskActionId]/newCustomStatus"/>

    <!-- add a name and description to links and endstate and port info -->
    <xsl:template match="link">
        <link>
            <xsl:variable name="fromProcessItemId"><xsl:value-of select="fromProcessItemId" /></xsl:variable>
            <xsl:choose>
            <xsl:when test="../item[processItemId = $fromProcessItemId]/tWComponentName = 'Switch'">
            <xsl:attribute name="name"><xsl:value-of select="endState" /></xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
            <xsl:attribute name="name">Untitled</xsl:attribute>
            </xsl:otherwise>            
            </xsl:choose>
            <description isNull="true"/>
            <endStateId><xsl:value-of select="endState" /></endStateId>
            <fromItemPort locationId="rightCenter" portType="1" />
            <toItemPort locationId="leftCenter" portType="2" />
            <xsl:apply-templates/>
        </link>
    </xsl:template>

    <!-- convert process item vars -->
    <xsl:template match="item">
        <item>
            <xsl:apply-templates/>
            <xsl:apply-templates select="java:com.lombardisoftware.expimp.PSExportImportUtils.convertPrePost(processItemVars[assignmentType='1'], '1')"/>
            <xsl:apply-templates select="java:com.lombardisoftware.expimp.PSExportImportUtils.convertPrePost(processItemVars[assignmentType='2'], '2')"/>
        </item>
    </xsl:template>

    <!-- Drop the processItemVars -->
    <xsl:template match="processItemVars"/>

    <!-- Under the old system newStatusOption = 2 meant ignore the newStatus value. -->
    <!-- Now it must be null if it is to be ignored. -->
    <xsl:template match="TWComponent[taskActionId]/newStatus[../newStatusOption = '2']">
        <newStatus isNull='true'/>
    </xsl:template>

    <!-- Pointy Hash conversion -->
    <xsl:template match="TWComponent[taskSenderId]/customStatus">
        <xsl:call-template name="convertPointyHash">
            <xsl:with-param name="limit">80</xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="TWComponent[taskSenderId]/category">
        <xsl:call-template name="convertPointyHash">
            <xsl:with-param name="limit">80</xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="TWComponent[taskSenderId]/otherTaskId">
        <xsl:call-template name="convertPointyHash">
            <xsl:with-param name="limit">64</xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="TWComponent[taskSenderId]/calendarName">
        <xsl:call-template name="convertPointyHash">
            <xsl:with-param name="limit">255</xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="TWComponent[taskSenderId]/dueDateIncrData">
        <xsl:call-template name="convertPointyHash">
            <xsl:with-param name="limit">255</xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="TWComponent[taskSenderId]/dueDateFixedData">
        <xsl:call-template name="convertPointyHash">
            <xsl:with-param name="limit">255</xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="TWComponent[taskActionId]/newPriorityScript">
        <xsl:call-template name="convertPointyHash">
            <xsl:with-param name="limit">255</xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="TWComponent[taskActionId]/newStatusScript">
        <xsl:call-template name="convertPointyHash">
            <xsl:with-param name="limit">255</xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="TWComponent[taskActionId]/calendarName">
        <xsl:call-template name="convertPointyHash">
            <xsl:with-param name="limit">255</xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="TWComponent[taskActionId]/dueDateIncrData">
        <xsl:call-template name="convertPointyHash">
            <xsl:with-param name="limit">255</xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="TWComponent[taskActionId]/dueDateFixedData">
        <xsl:call-template name="convertPointyHash">
            <xsl:with-param name="limit">255</xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="TWComponent[taskActionId]/newCategory">
        <xsl:call-template name="convertPointyHash">
            <xsl:with-param name="limit">80</xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="TWComponent[taskActionId]/otherTaskId">
        <xsl:call-template name="convertPointyHash">
            <xsl:with-param name="limit">64</xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <!-- Don't convert output parameters and convert TWComponent and underCoverAgent parameters -->
    <xsl:template match="TWComponent/parameterMapping/value">
        <xsl:variable name="parameterId" select="../processParameterId"/>
        <xsl:choose>
            <xsl:when test="count(key('outputParameter', $parameterId)) &gt; 0">
                <value>
                    <xsl:choose>
                        <xsl:when test="@isNull='true'">
                            <xsl:attribute name="isNull">true</xsl:attribute>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:if test="../../subProcessId">
                                <xsl:choose>
                                    <xsl:when test="../namespace = '1'">tw.global.</xsl:when>
                                    <xsl:when test="../namespace = '2'">tw.local.</xsl:when>
                                    <xsl:when test="../namespace = '3'">tw.sst.</xsl:when>
                                </xsl:choose>
                            </xsl:if>
                            <xsl:value-of select="."/>
                        </xsl:otherwise>
                    </xsl:choose>
                </value>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="convertPointyHash">
                    <xsl:with-param name="limit">1000000</xsl:with-param>
                </xsl:call-template>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template match="underCoverAgent/parameterMapping/value">
        <xsl:variable name="parameterId" select="../processParameterId"/>
        <xsl:choose>
            <xsl:when test="count(key('outputParameter', $parameterId)) &gt; 0">
                <value>
                    <xsl:choose>
                        <xsl:when test="@isNull='true'">
                            <xsl:attribute name="isNull">true</xsl:attribute>
                        </xsl:when>
                        <xsl:otherwise><xsl:value-of select="."/></xsl:otherwise>
                    </xsl:choose>
                </value>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="convertPointyHash">
                    <xsl:with-param name="limit">1000000</xsl:with-param>
                </xsl:call-template>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="CAPVariables/variableValue">
        <xsl:call-template name="convertPointyHash">
            <xsl:with-param name="limit">4000</xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="processParameter/defaultValue">
        <xsl:call-template name="convertPointyHash">
            <xsl:with-param name="limit">1000000</xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="processVariable/defaultValue">
        <xsl:call-template name="convertPointyHash">
            <xsl:with-param name="limit">1000000</xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="globalVariable/defaultValue">
        <xsl:call-template name="convertPointyHash">
            <xsl:with-param name="limit">1000000</xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:template name="convertPointyHash">
        <xsl:param name="n" select="."/>
        <xsl:param name="limit">0</xsl:param>
        <xsl:element name="{local-name($n)}">
            <xsl:choose>
                <xsl:when test="$n[@isNull='true']">
                    <xsl:attribute name="isNull">true</xsl:attribute>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:variable name="js" select="java:com.lombardisoftware.expimp.PSExportImportUtils.convertFromPointyHashToExpression($n)"/>
                    <xsl:if test="string-length($js) &gt; $limit">
                        <xsl:variable name="e">Conversion of <xsl:value-of select="local-name($n)"/> value <xsl:value-of select="$n"/> from pointy hash to javascript failed. Converted value <xsl:value-of select="$js"/> longer than limit of <xsl:value-of select="$limit"/> characters.</xsl:variable>
                        <xsl:value-of select="java:com.lombardisoftware.expimp.PSExportImportUtils.throwException($e)"/>
                    </xsl:if>
                    <xsl:value-of select="$js"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:element>
    </xsl:template>

    <!-- layout conversion -->
    <xsl:template match="item/uiData">
        <layoutData>
            <xsl:call-template name="xyCoordinates"/>
            <xsl:for-each select='entry[@key="ERROR_LINK_LAYOUT"][1]/value'>
                <errorLink>
                    <xsl:call-template name="controlPoints"/>
                </errorLink>
            </xsl:for-each>
        </layoutData>
    </xsl:template>

    <xsl:template match='note/uiData'>
        <layoutData>
            <xsl:attribute name='x'><xsl:value-of select='entry[@key="XPOS"]/value' /></xsl:attribute>
            <xsl:attribute name='y'><xsl:value-of select='entry[@key="YPOS"]/value' /></xsl:attribute>
            <xsl:attribute name='width'><xsl:value-of select='entry[@key="WIDTH"]/value' /></xsl:attribute>
            <xsl:attribute name='height'><xsl:value-of select='entry[@key="HEIGHT"]/value' /></xsl:attribute>
        </layoutData>
    </xsl:template>

    <xsl:template match='process/uiData'>
        <layoutData>
            <xsl:for-each select='entry[@key="START_POINT_LAYOUT"][1]/value/entry[@key="ERROR_LINK_LAYOUT"][1]/value'>
                <errorLinkLayoutData>
                    <xsl:call-template name='controlPoints'/>
                </errorLinkLayoutData>
            </xsl:for-each>
        </layoutData>
        <startPoint>
            <xsl:for-each select='entry[@key="START_POINT_LAYOUT"][1]/value'>
                <layoutData>
                    <xsl:call-template name='xyCoordinates'/>
                </layoutData>
            </xsl:for-each>
        </startPoint>
        <!-- Start link is optional so only create it if one exists in the layout -->
        <xsl:if test='entry[@key="START_LINK_LAYOUT"][1]/value'>
            <startLink>
                <xsl:for-each select='entry[@key="START_LINK_LAYOUT"][1]/value'>
                    <fromPort locationId="rightCenter" portType="1" />
                    <toPort locationId="leftCenter" portType="2" />
                    <layoutData>
                        <xsl:call-template name='controlPoints'/>
                    </layoutData>
                </xsl:for-each>
            </startLink>
        </xsl:if>
    </xsl:template>

    <xsl:template match="link/uiData">
        <layoutData>
            <showEndState>true</showEndState>
            <xsl:call-template name="controlPoints"/>
        </layoutData>
    </xsl:template>

    <xsl:template name="xyCoordinates">
        <xsl:choose>
            <xsl:when test="@isNull = 'true' or count(entry/value) &lt; 2">
                <xsl:attribute name="x">1</xsl:attribute>
                <xsl:attribute name="y">1</xsl:attribute>
            </xsl:when>
            <xsl:otherwise>
                <xsl:attribute name="x"><xsl:value-of select='entry[@key="XPOS"]/value' /></xsl:attribute>
                <xsl:attribute name="y"><xsl:value-of select='entry[@key="YPOS"]/value' /></xsl:attribute>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template name="controlPoints">
        <controlPoints>
            <!--
            <xsl:apply-templates select='entry[@key="Points"]/value/entry/value' mode="link">
                <xsl:sort select="../key" data-type="number"/>
            </xsl:apply-templates>
            -->
        </controlPoints>
    </xsl:template>

    <xsl:template match="value" mode="link">
        <controlPoint>
            <xsl:attribute name="x"><xsl:value-of select="x"/></xsl:attribute>
            <xsl:attribute name="y"><xsl:value-of select="y"/></xsl:attribute>
        </controlPoint>
    </xsl:template>

	    <!-- This is the identity template
-->
    <xsl:template match="@*|node()">
        <xsl:copy>
            <xsl:apply-templates select="@*|node()"/>
        </xsl:copy>
    </xsl:template>
</xsl:stylesheet>
