<?xml version="1.0"?>

<xsl:stylesheet
    version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:java="http://xml.apache.org/xslt/java"
    exclude-result-prefixes="java">

    <xsl:output method="xml" indent="yes"/>

    <xsl:template match="/teamworks">
        <teamworks version="Pebbles">
            <xsl:apply-templates/>
        </teamworks>
    </xsl:template>

    <xsl:template match="/teamworks/process/item">
        <xsl:choose>
            <xsl:when test="tWComponentName = 'ExitPoint'">
                <item>
                    <xsl:apply-templates/>
                    <guid>imp:<xsl:value-of select="../@name"/>/<xsl:value-of select="name"/></guid>
                </item>
            </xsl:when>
            <xsl:otherwise>
                <xsl:variable name="newGUID" select="java:com.lombardisoftware.core.GUID.generateGUID()"/>
                <item>
                    <xsl:apply-templates/>
                    <guid>imp:<xsl:value-of select="$newGUID"/></guid>
                </item>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="/teamworks/process/item[tWComponentName = 'TaskAction']/TWComponent">
        <TWComponent>
            <xsl:apply-templates/>
            <calendarName isNull="true"/>
            <isIgnoreException>true</isIgnoreException>
            <subject isNull="true"/>
            <subjectOption>1</subjectOption>
            <dueInOption>1</dueInOption>>
            <dueDateIncrData isNull="true"/>
            <dueDateFixedData isNull="true"/>
            <dueDateIncrType>1</dueDateIncrType>
            <dueDateSpecificDate isNull="true"/>
            <newStatusOption>1</newStatusOption>
            <newStatusScript isNull="true"/>
            <isPriorityActive>false</isPriorityActive>
            <priorityOption>1</priorityOption>
            <newPriorityId isNull="true"/>
            <newPriorityScript isNull="true"/>
            <isSubjectActive>false</isSubjectActive>
            <subjectOption>1</subjectOption>
            <subjectScript isNull="true"/>
            <isNarrativeActive>false</isNarrativeActive>
            <narrativeOption>1</narrativeOption>
            <narrativeScript isNull="true"/>
        </TWComponent>
    </xsl:template>


    <xsl:template match="/teamworks/process/item[tWComponentName = 'TaskSender']/TWComponent">
        <TWComponent>
            <xsl:apply-templates/>
            <dueInOption>1</dueInOption>>
            <dueDateIncrData>
                <xsl:value-of select="dueDateIncrNumber"/>
            </dueDateIncrData>
            <xsl:choose>
                <xsl:when test="dueDateFixedTime/@isNull = 'true'">
                    <dueDateFixedData isNull="true"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:variable name="currentDueDateFixedTime" select="string(dueDateFixedTime)"/>
                    <xsl:variable name="newDueDateFixedTime" select="java:com.lombardisoftware.expimp.PSExportImportUtils.convertTaskSenderDueDateTimeToString($currentDueDateFixedTime)"/>
                    <dueDateFixedData>
                        <xsl:value-of select="$newDueDateFixedTime"/>
                    </dueDateFixedData>
                </xsl:otherwise>
            </xsl:choose>
            <dueDateSpecificDate isNull="true"/>
        </TWComponent>
    </xsl:template>

    <xsl:template match="/teamworks/layout">
        <xsl:variable name="newGUID" select="java:com.lombardisoftware.core.GUID.generateGUID()"/>
        <layout id="{@id}" name="{@name}">
            <xsl:apply-templates/>
            <metaDataLabel isNull="true"/>
            <metaDataUI isNull="true"/>
            <guid>imp:<xsl:value-of select="$newGUID"/></guid>

            <xsl:if test="documentType = 'coach'">
                <layoutParam name="Image1">
                  <layoutParamId isNull="true" />
                  <layoutId><xsl:value-of select="layoutId"/></layoutId>
                  <value isNull="true" />
                  <type>2</type>
                  <seq>1</seq>
                </layoutParam>
                <layoutParam name="Image2">
                  <layoutParamId isNull="true" />
                  <layoutId><xsl:value-of select="layoutId"/></layoutId>
                  <value isNull="true" />
                  <type>2</type>
                  <seq>2</seq>
                </layoutParam>
                <layoutParam name="Image3">
                  <layoutParamId isNull="true" />
                  <layoutId><xsl:value-of select="layoutId"/></layoutId>
                  <value isNull="true" />
                  <type>2</type>
                  <seq>3</seq>
                </layoutParam>
                <layoutParam name="Message1">
                  <layoutParamId isNull="true" />
                  <layoutId><xsl:value-of select="layoutId"/></layoutId>
                  <value isNull="true" />
                  <type>1</type>
                  <seq>4</seq>
                </layoutParam>
                <layoutParam name="Message2">
                  <layoutParamId isNull="true" />
                  <layoutId><xsl:value-of select="layoutId"/></layoutId>
                  <value isNull="true" />
                  <type>1</type>
                  <seq>5</seq>
                </layoutParam>
            </xsl:if>
        </layout>
    </xsl:template>

    <xsl:template match="/teamworks/layout/layoutParam">
        <layoutParam name="{@name}">
            <xsl:apply-templates/>
            <type isNull="true"/>
        </layoutParam>
    </xsl:template>

    <xsl:template match="/teamworks/process/item[tWComponentName = 'Coach']/TWComponent/CoachButtons">
        <CoachButtons>
            <xsl:apply-templates/>
            <metaData isNull="true"/>
        </CoachButtons>
    </xsl:template>

    <xsl:template match="/teamworks/globalVariable">
        <xsl:variable name="newGUID" select="java:com.lombardisoftware.core.GUID.generateGUID()"/>
        <globalVariable id="{@id}" name="{@name}">
            <xsl:apply-templates/>
            <taskCustomColumn isNull="true"/>
            <guid>imp:<xsl:value-of select="$newGUID"/></guid>
        </globalVariable>
    </xsl:template>

    <xsl:template match="/teamworks/trackingGroup">
        <xsl:variable name="newGUID" select="java:com.lombardisoftware.core.GUID.generateGUID()"/>
        <trackingGroup id="{@id}" name="{@name}">
            <xsl:apply-templates/>
            <isEnabled>true</isEnabled>
            <guid>imp:<xsl:value-of select="$newGUID"/></guid>
        </trackingGroup>
    </xsl:template>

    <xsl:template match="/teamworks/connector">
        <xsl:variable name="newGUID" select="java:com.lombardisoftware.core.GUID.generateGUID()"/>
        <connector id="{@id}" name="{@name}">
            <xsl:apply-templates/>
            <guid>imp:<xsl:value-of select="$newGUID"/></guid>
        </connector>
    </xsl:template>

    <xsl:template match="/teamworks/integrationComponent">
        <xsl:variable name="newGUID" select="java:com.lombardisoftware.core.GUID.generateGUID()"/>
        <integrationComponent id="{@id}" name="{@name}">
            <xsl:apply-templates/>
            <guid>imp:<xsl:value-of select="$newGUID"/></guid>
        </integrationComponent>
    </xsl:template>

    <xsl:template match="/teamworks/process">
        <xsl:variable name="newGUID" select="java:com.lombardisoftware.core.GUID.generateGUID()"/>
        <process id="{@id}" name="{@name}">
            <xsl:apply-templates/>
            <guid>imp:<xsl:value-of select="$newGUID"/></guid>
        </process>
    </xsl:template>

    <xsl:template match="/teamworks/webScript">
        <xsl:variable name="newGUID" select="java:com.lombardisoftware.core.GUID.generateGUID()"/>
        <webScript id="{@id}" name="{@name}">
            <xsl:apply-templates/>
            <guid>imp:<xsl:value-of select="$newGUID"/></guid>
        </webScript>
    </xsl:template>

    <xsl:template match="/teamworks/underCoverAgent">
        <xsl:variable name="newGUID" select="java:com.lombardisoftware.core.GUID.generateGUID()"/>
        <underCoverAgent id="{@id}" name="{@name}">
            <xsl:apply-templates/>
            <guid>imp:<xsl:value-of select="$newGUID"/></guid>
        </underCoverAgent>
    </xsl:template>

    <xsl:template match="/teamworks/epv">
        <xsl:variable name="newGUID" select="java:com.lombardisoftware.core.GUID.generateGUID()"/>
        <epv id="{@id}" name="{@name}">
            <xsl:apply-templates/>
            <guid>imp:<xsl:value-of select="$newGUID"/></guid>
        </epv>
    </xsl:template>

    <xsl:template match="/teamworks/report">
        <xsl:variable name="newGUID" select="java:com.lombardisoftware.core.GUID.generateGUID()"/>
        <report id="{@id}" name="{@name}">
            <xsl:apply-templates/>
            <guid>imp:<xsl:value-of select="$newGUID"/></guid>
        </report>
    </xsl:template>

    <xsl:template match="/teamworks/scoreboard">
        <xsl:variable name="newGUID" select="java:com.lombardisoftware.core.GUID.generateGUID()"/>
        <scoreboard id="{@id}" name="{@name}">
            <xsl:apply-templates/>
            <guid>imp:<xsl:value-of select="$newGUID"/></guid>
        </scoreboard>
    </xsl:template>

    <xsl:template match="/teamworks/timingInterval">
        <xsl:variable name="newGUID" select="java:com.lombardisoftware.core.GUID.generateGUID()"/>
        <timingInterval id="{@id}" name="{@name}">
            <xsl:apply-templates/>
            <guid>imp:<xsl:value-of select="$newGUID"/></guid>
        </timingInterval>
    </xsl:template>

    <xsl:template match="/teamworks/twClass">
        <xsl:variable name="newGUID" select="java:com.lombardisoftware.core.GUID.generateGUID()"/>
        <twClass id="{@id}" name="{@name}">
            <xsl:apply-templates/>
            <guid>imp:<xsl:value-of select="$newGUID"/></guid>
        </twClass>
    </xsl:template>

    <xsl:template match="/teamworks/webService">
        <xsl:variable name="newGUID" select="java:com.lombardisoftware.core.GUID.generateGUID()"/>
        <webService id="{@id}" name="{@name}">
            <xsl:apply-templates/>
            <guid>imp:<xsl:value-of select="$newGUID"/></guid>
        </webService>
    </xsl:template>

    <xsl:template match="/teamworks/alertType">
        <xsl:variable name="newGUID" select="java:com.lombardisoftware.core.GUID.generateGUID()"/>
        <alertType id="{@id}" name="{@name}">
            <xsl:apply-templates/>
            <guid>imp:<xsl:value-of select="$newGUID"/></guid>
        </alertType>
    </xsl:template>

    <xsl:template match="/teamworks/alertSeverity">
        <xsl:variable name="newGUID" select="java:com.lombardisoftware.core.GUID.generateGUID()"/>
        <alertSeverity id="{@id}" name="{@name}">
            <xsl:apply-templates/>
            <guid>imp:<xsl:value-of select="$newGUID"/></guid>
        </alertSeverity>
    </xsl:template>

    <xsl:template match="/teamworks/priority">
        <xsl:variable name="newGUID" select="java:com.lombardisoftware.core.GUID.generateGUID()"/>
        <priority id="{@id}" name="{@name}">
            <xsl:apply-templates/>
            <guid>imp:<xsl:value-of select="$newGUID"/></guid>
        </priority>
    </xsl:template>

    <xsl:template match="/teamworks/customStatus">
        <xsl:variable name="newGUID" select="java:com.lombardisoftware.core.GUID.generateGUID()"/>
        <customStatus id="{@id}" name="{@name}">
            <xsl:apply-templates/>
            <guid>imp:<xsl:value-of select="$newGUID"/></guid>
        </customStatus>
    </xsl:template>

    <xsl:template match="/teamworks/calendar">
        <xsl:variable name="newGUID" select="java:com.lombardisoftware.core.GUID.generateGUID()"/>
        <calendar id="{@id}" name="{@name}">
            <xsl:apply-templates/>
            <guid>imp:<xsl:value-of select="$newGUID"/></guid>
        </calendar>
    </xsl:template>

    <xsl:template match="/teamworks/businessRule">
        <xsl:variable name="newGUID" select="java:com.lombardisoftware.core.GUID.generateGUID()"/>
        <businessRule id="{@id}" name="{@name}">
            <xsl:apply-templates/>
            <guid>imp:<xsl:value-of select="$newGUID"/></guid>
        </businessRule>
    </xsl:template>

    <!-- This is the identity template -->
    <xsl:template match="@*|node()">
        <xsl:copy>
            <xsl:apply-templates select="@*|node()"/>
        </xsl:copy>
    </xsl:template>
</xsl:stylesheet>